import { AppSyncAuthConfiguration, DeploymentResources, Template, TransformerPluginProvider, TransformHostProvider, TransformerLog } from '@aws-amplify/graphql-transformer-interfaces';
import type { TransformParameters } from '@aws-amplify/graphql-transformer-interfaces';
import { ResolverConfig } from '../config/transformer-config';
import { GraphQLApi } from '../graphql-api';
import { TransformerOutput } from '../transformer-context/output';
import { StackManager } from '../transformer-context/stack-manager';
import { UserDefinedSlot, OverrideConfig, DatasourceTransformationConfig } from './types';
import { DocumentNode } from 'graphql/language';
export interface GraphQLTransformOptions {
    readonly transformers: TransformerPluginProvider[];
    readonly stackMapping?: StackMapping;
    readonly authConfig?: AppSyncAuthConfiguration;
    readonly stacks?: Record<string, Template>;
    readonly transformParameters?: Partial<TransformParameters>;
    readonly host?: TransformHostProvider;
    readonly sandboxModeEnabled?: boolean;
    readonly disableResolverDeduping?: boolean;
    readonly userDefinedSlots?: Record<string, UserDefinedSlot[]>;
    readonly resolverConfig?: ResolverConfig;
    readonly overrideConfig?: OverrideConfig;
    readonly legacyApiKeyEnabled?: boolean;
}
export type StackMapping = {
    [resourceId: string]: string;
};
export declare class GraphQLTransform {
    private readonly options;
    private transformers;
    private stackMappingOverrides;
    private app;
    private readonly authConfig;
    private readonly resolverConfig?;
    private readonly userDefinedSlots;
    private readonly overrideConfig?;
    private readonly disableResolverDeduping?;
    private readonly legacyApiKeyEnabled?;
    private readonly transformParameters;
    private seenTransformations;
    private logs;
    constructor(options: GraphQLTransformOptions);
    preProcessSchema(schema: DocumentNode): DocumentNode;
    transform(schema: string, datasourceConfig?: DatasourceTransformationConfig): DeploymentResources;
    protected generateGraphQlApi(stackManager: StackManager, output: TransformerOutput): GraphQLApi;
    private synthesize;
    private collectResolvers;
    private transformObject;
    private transformField;
    private transformArgument;
    private transformInterface;
    private transformScalar;
    private transformUnion;
    private transformEnum;
    private transformEnumValue;
    private transformInputObject;
    private transformInputField;
    getLogs(): TransformerLog[];
}
//# sourceMappingURL=transform.d.ts.map